badge_dropdown: Drop-down badge

View source: R/ui_containers.R

badge_dropdownR Documentation

Drop-down badge

Description

Drop-down button in a form of a badge with bg-primary as default style Clicking badge shows a drop-down containing any HTML element. Folded drop-down doesn't trigger display output which means that items rendered using ⁠render*⁠ will be recomputed only when drop-down is show.

Usage

badge_dropdown(id, label, content)

Arguments

id

(character(1)) shiny module's id

label

(shiny.tag) Label displayed on a badge.

content

(shiny.tag) Content of a drop-down.

Value

A shiny.tag object representing a drop-down badge component to display the options.


teal.picks documentation built on Oct. 9, 2026, 5:07 p.m.