determine: A method that should take a type and resolve it.

View source: R/resolver.R

determineR Documentation

A method that should take a type and resolve it.

Description

Generic that makes the minimal check on spec. Responsible of subsetting/extract the data received and check that the type matches

Usage

determine(x, data)

Arguments

x

The specification to resolve.

data

The minimal data required.

Value

A list with two elements, the type resolved and the data extracted.


teal.picks documentation built on Oct. 9, 2026, 5:07 p.m.