dot-call_dplyr_select: 'dplyr::select' call

.call_dplyr_selectR Documentation

dplyr::select call

Description

Create dplyr::select call from dataname and variables

Usage

.call_dplyr_select(dataname, variables)

Arguments

dataname

(character(1)) name of the dataset

variables

(list of character) variables to select. If list is named then variables will be renamed if their name is different than its value (this produces a call ⁠select(..., <name> = <value>)⁠).

Value

call.


teal.picks documentation built on Oct. 9, 2026, 5:07 p.m.