| .is_delayed | R Documentation |
Determine whether list of picks/picks or pick are delayed.
When "pick" is created it could be either:
quosure when tidyselect helper used (delayed)
function when predicate function provided (delayed)
atomic when vector of choices/selected provided (eager)
.is_delayed(x)
x |
( |
A logical(1) indicating if any of the elements in picks is delayed.,
For a single pick, such as datasets(), variables() or values(),
it checks if either choices or selected are delayed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.