dot-validate_join_keys: Check if datasets can be merged in topological order

.validate_join_keysR Documentation

Check if datasets can be merged in topological order

Description

Determines the topological order from join_keys, then checks that each dataset can be joined with at least one of the previously accumulated datasets.

Usage

.validate_join_keys(selectors, join_keys)

Arguments

selectors

(⁠named list⁠) A named list of selector objects. Each element can be:

  • A picks object defining dataset and variable selections

  • A reactive expression returning a picks object The names of this list are used as identifiers for tracking which variables come from which selector.

join_keys

(join_keys) The join keys object

Value

TRUE if validation passes, otherwise raises a validation error with details on which datasets cannot be merged and why.


teal.picks documentation built on Oct. 9, 2026, 5:07 p.m.