| helper_functions_pick | R Documentation |
Helper functions for pick objects generated from
datasets(), variables() or values():
is_pick_multiple() checks if a pick has the multiple attribute set to TRUE.
is_pick_fixed() checks if a pick has the fixed attribute set to TRUE.
is_pick_ordered() checks if a pick has the ordered attribute set to TRUE.
is_pick_multiple(x)
is_pick_fixed(x)
is_pick_ordered(x)
x |
( |
TRUE if the pick has the attribute set to TRUE,
FALSE otherwise.
p <- picks(datasets("iris"), variables(), values())
is_pick_multiple(p$variables)
is_pick_fixed(p$variables)
is_pick_ordered(p$variables)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.