Read all teal.picks exported values for a module namespace.
Source:R/helper-shinytest2.R
app_driver_teal_picks_exports.RdThe module namespace is inferred from the summary badge id in the DOM,
then used to filter exported values.
Use this helper only for tests and development workflows.
Examples
if (FALSE) { # \dontrun{
if (requireNamespace("shinytest2", quietly = TRUE)) {
data <- within(teal.data::teal_data(), iris <- iris)
test_picks <- picks(
datasets("iris"),
variables(choices = c("Sepal.Length", "Sepal.Width"), selected = "Sepal.Length")
)
teal_app <- teal::init(
data = data,
modules = teal::modules(tm_merge(label = "badge test", picks = list(pick = test_picks)))
)
app_driver <- suppressWarnings(shinytest2::AppDriver$new(
shiny::shinyApp(ui = teal_app$ui, server = teal_app$server)
))
on.exit(app_driver$stop())
app_driver$wait_for_idle()
names(app_driver_teal_picks_exports(app_driver, "pick"))
}
} # }