View source: R/ui_containers.R
| badge_dropdown | R Documentation |
Drop-down button in a form of a badge with bg-primary as default style
Clicking badge shows a drop-down containing any HTML element. Folded drop-down
doesn't trigger display output which means that items rendered using render*
will be recomputed only when drop-down is show.
badge_dropdown(id, label, content)
id |
( |
label |
( |
content |
( |
A shiny.tag object representing a drop-down badge component to display the options.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.