Skip to contents

Generic that makes the minimal check on spec. Responsible of subsetting/extract the data received and check that the type matches

Usage

determine(x, data)

Arguments

x

The specification to resolve.

data

The minimal data required.

Value

A list with two elements, the type resolved and the data extracted.