Generic that makes the minimal check on spec. Responsible of subsetting/extract the data received and check that the type matches
Generic that makes the minimal check on spec. Responsible of subsetting/extract the data received and check that the type matches