| determine | R Documentation |
Generic that makes the minimal check on spec. Responsible of subsetting/extract the data received and check that the type matches
determine(x, data)
x |
The specification to resolve. |
data |
The minimal data required. |
A list with two elements, the type resolved and the data extracted.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.