| .is_tidyselect | R Documentation |
tidyselectchoices and selected can be provided using tidyselect, (e.g. tidyselect::everything()
tidyselect::where(), tidyselect::starts_with()). These functions can't be called
independently but rather as an argument of function which consumes them.
.is_tidyselect safely determines if x can be evaluated with tidyselect::eval_select()
.is_tidyselect(x)
x |
|
logical(1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.