| .validate_join_keys | R Documentation |
Determines the topological order from join_keys, then checks that each dataset can be joined with at least one of the previously accumulated datasets.
.validate_join_keys(selectors, join_keys)
selectors |
(
|
join_keys |
( |
TRUE if validation passes, otherwise raises a validation
error with details on which datasets cannot be merged and why.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.