Skip to contents

Helper functions for pick objects generated from datasets(), variables() or values():

  • is_pick_multiple() checks if a pick has the multiple attribute set to TRUE.

  • is_pick_fixed() checks if a pick has the fixed attribute set to TRUE.

  • is_pick_ordered() checks if a pick has the ordered attribute set to TRUE.

Usage

is_pick_multiple(x)

is_pick_fixed(x)

is_pick_ordered(x)

Arguments

x

(datasets, variables or values) pick to check.

Value

TRUE if the pick has the attribute set to TRUE, FALSE otherwise.

Examples

p <- picks(datasets("iris"), variables(), values())

is_pick_multiple(p$variables)
#> [1] FALSE

is_pick_fixed(p$variables)
#> [1] FALSE

is_pick_ordered(p$variables)
#> [1] FALSE