| interaction_vars | R Documentation |
tidyselectUsed inside tidyselect expressions to declare a pair of variables that
interact with each other. The pair is recorded in the selection environment
and the positions of both variables within the available variables are
returned.
interaction_vars(
var1,
var2,
vars = tidyselect::peek_vars(fn = "interaction_vars")
)
var1 |
An unquoted variable name. |
var2 |
An unquoted variable name that interacts with |
vars |
Character vector of available variable names, retrieved
automatically via |
An integer vector of length 2 giving the positions of var1 and
var2 in vars, or NA where a variable is not found.
picks(
datasets("ADAE"),
variables(
c(AGE, RACE, interaction_vars("COUNTRY", "RACE")),
selected = "COUNTRY:RACE",
multiple = TRUE
),
values()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.