View source: R/tidyselect-helpers.R
| ranged | R Documentation |
Helper to work with ranges. Setting choices or selected to range using
ranged() in any of them will automatically create a numeric, Date or POSIXct
input to filter. variables(choices) must only refer to numeric, Date, or POSIXct
columns. An informative error is raised if the resolved column type is unsupported.
ranged(min = -Inf, max = Inf)
min |
( |
max |
( |
A function that allows the use of a range in choices or selected of values() in
numeric, Date, or POSIXct variables.
p <- picks(
datasets(choices = "mtcars"),
variables(choices = is.numeric, selected = 1),
values(choices = ranged(), ranged(20, 30))
)
resolver(data = list("mtcars label" = mtcars), x = p)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.