Example teal::module containing interactive inputs and displaying results of merge.
Usage
tm_merge(label = "merge-module", picks, transformators = list())Arguments
- label
(
character(1)) Label shown in the navigation item for the module or module group. Formodules()defaults to"root". SeeDetails.- picks
(
listofpicks)- transformators
(
listofteal_transform_module) that will be applied to transform module's data input. To learn more checkvignette("transform-input-data", package = "teal").
Value
A teal::module object that merges datasets based on user selections and displays the results.
Examples
library(teal)
#> Loading required package: teal.slice
#>
#> You are using teal version 1.1.0
#>
#> Attaching package: ‘teal’
#> The following objects are masked from ‘package:teal.slice’:
#>
#> as.teal_slices, teal_slices
data <- within(teal.data::teal_data(), {
iris <- iris
mtcars <- mtcars
})
app <- init(
data = data,
modules = modules(
modules(
label = "Testing modules",
tm_merge(
label = "non adam",
picks = list(
a = picks(
datasets("iris", "iris"),
variables(
choices = c("Sepal.Length", "Species"),
selected = "Sepal.Length"
),
values()
)
)
)
)
)
)
if (interactive()) {
shinyApp(app$ui, app$server, enableBookmarking = "server")
}