| tm_merge | R Documentation |
Example teal::module containing interactive inputs and displaying results of merge.
tm_merge(label = "merge-module", picks, transformators = list())
label |
( |
picks |
( |
transformators |
( |
A teal::module object that merges datasets based on user selections and displays the results.
library(teal)
data <- within(teal.data::teal_data(), {
iris <- iris
mtcars <- mtcars
})
app <- init(
data = data,
modules = modules(
modules(
label = "Testing modules",
tm_merge(
label = "non adam",
picks = list(
a = picks(
datasets("iris", "iris"),
variables(
choices = c("Sepal.Length", "Species"),
selected = "Sepal.Length"
),
values()
)
)
)
)
)
)
if (interactive()) {
shinyApp(app$ui, app$server, enableBookmarking = "server")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.